// **************************************************************************
// * This file is part of the FreeFileSync project. It is distributed under *
// * GNU General Public License: http://www.gnu.org/licenses/gpl.html       *
// * Copyright (C) 2008-2010 ZenJu (zhnmju123 AT gmx.de)                    *
// **************************************************************************
//
#ifndef TASKBAR_SEVEN_DLL_H
#define TASKBAR_SEVEN_DLL_H

#ifdef TASKBAR_SEVEN_DLL_EXPORTS
#define DLL_FUNCTION_DECLARATION extern "C" __declspec(dllexport)
#else
#define DLL_FUNCTION_DECLARATION extern "C" __declspec(dllimport)
#endif


namespace TaskbarSeven
{
enum TaskBarStatus
{
    STATUS_NOPROGRESS,
    STATUS_INDETERMINATE,
    STATUS_NORMAL,
    STATUS_ERROR,
    STATUS_PAUSED
};

typedef size_t TBHandle;


//COM needs to be initialized before calling any of these functions! CoInitializeEx/CoUninitialize
DLL_FUNCTION_DECLARATION
TBHandle init(); //returns handle; 0 on failure

DLL_FUNCTION_DECLARATION
void release(TBHandle handle); //release taskbar handle

DLL_FUNCTION_DECLARATION
bool setStatus(TBHandle handle,
               void* hwnd, //HWND: window assciated to the taskbar icon
               TaskBarStatus status);


DLL_FUNCTION_DECLARATION
bool setProgress(TBHandle handle,
                 void* hwnd, //HWND: window assciated to the taskbar icon
                 size_t current,
                 size_t total);

//if any of the functions above returns 'false', this message returns last error
void getLastError(wchar_t* errorMessage, size_t errorBufferLen);


//function typedefs
typedef TBHandle (*initFct)();
typedef void (*releaseFct)(TBHandle handle);
typedef bool (*setStatusFct)(TBHandle handle, void* hwnd, TaskBarStatus status);
typedef bool (*setProgressFct)(TBHandle handle, void* hwnd, size_t current, size_t total);
typedef void (*getLastErrorFct)(wchar_t* errorMessage, size_t errorBufferLen);
}

#endif //TASKBAR_SEVEN_DLL_H